@@ -480,12 +480,6 @@ from data.models.models import ChannelStats, DataTransformer, DataTransformerCon
 #                                                      extra=1,exclude =['updated_at','created_at'],formset=DataTransformerForm)
 
 class DataConstantsTransformerForm(forms.ModelForm):
-    id = forms.UUIDField(required=True,
-                         widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4)
-
-    index = forms.IntegerField(required=False,
-                               widget=forms.HiddenInput(attrs={'class': 'form-control'}),
-                               initial=0)
     value = forms.CharField(required=True,
                             widget=forms.TextInput(attrs={'class': 'form-control'}))
     data_transformer = forms.ModelChoiceField(required=True, queryset=DataTransformer.objects.all(),
@@ -493,7 +487,7 @@ class DataConstantsTransformerForm(forms.ModelForm):
 
     class Meta:
         model = DataTransformerConstants
-        fields = ('__all__')
+        fields = ('value','data_transformer')
 
 
 # class HardwareTransformerForm(forms.ModelForm):
@@ -651,7 +645,7 @@ class DataTransform(forms.ModelForm):
             if nested_data_transformer_form_data is not None and len(nested_data_transformer_form_data.keys()) > 0:
                 self.nested_data_transformer_form = dataTransformerInlineFormset(
                     instance=self.instance,
-                    data=self.data,
+                    data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
                     prefix=nested_data_transformer_form_prefix,
                     initial=[{'parent': str(self.instance.id)}],
@@ -661,10 +655,10 @@ class DataTransform(forms.ModelForm):
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
             queryset=self.instance.data_transformer_constants,
-            data=self.data,
+            data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=nested_constants_form_prefix,
-            initial=[{'data_transformer': str(self.instance.id)},{'data_transformer': str(self.instance.id)},{'data_transformer': str(self.instance.id)}]
+            initial=[{'data_transformer': str(self.fields['id'].initial)},{'data_transformer':  str(self.fields['id'].initial)},{'data_transformer':  str(self.fields['id'].initial)}]
 
         )
         self.nested_constants_form.extra = 0
@@ -694,7 +688,7 @@ class DataTransform(forms.ModelForm):
         print('instance: ' + str(self.instance.id))
         forms = '<div class="row"><div class="col-6">'
 
-        forms = super(DataTransform, self).as_p()
+        forms = forms + super(DataTransform, self).as_p()
         forms = forms + '</div><div class="col-6">'
 
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
@@ -828,7 +822,7 @@ class DataTransformRoot(forms.ModelForm):
 
                 self.nested_data_transformer_form = dataTransformerInlineFormset(
                     instance=self.instance,
-                    data=self.data,
+                    data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
                     prefix=nested_data_transformer_form_prefix,
                     initial=[{'parent': str(self.instance.pk),'accessory': str(self.instance.accessory.id)}],
@@ -839,7 +833,7 @@ class DataTransformRoot(forms.ModelForm):
             if nested_data_transformer_form_data is not None and len(nested_data_transformer_form_data.keys())>0:
                 self.nested_data_transformer_form = dataTransformerInlineFormset(
                     instance=self.instance,
-                    data=self.data,
+                    data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
                     prefix=nested_data_transformer_form_prefix,
                     initial=[{'parent': str(self.instance.pk),'accessory': str(self.instance.accessory.id)}],
@@ -850,7 +844,7 @@ class DataTransformRoot(forms.ModelForm):
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
             queryset=self.instance.data_transformer_constants,
-            data=self.data,
+            data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=nested_constants_form_prefix,
             initial=[{'data_transformer': str(self.instance.id)},{'data_transformer': str(self.instance.id)},{'data_transformer': str(self.instance.id)},{'data_transformer': str(self.instance.id)}]
